Documentation
¶
Overview ¶
A simple internal k-v store with the ability to expire a key
Index ¶
Examples ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Cache ¶
type Cache struct {
// contains filtered or unexported fields
}
func (*Cache) Flush ¶
func (c *Cache) Flush()
Flush all keys
- design considerations: best effort is made to reduce the gc cycle by manually close all the keys that are going to be deleted or replaced but doing a loop or making a storage for stopping all the timers are not worth the gain so they are spared when flushing
Click to show internal directories.
Click to hide internal directories.